Subject: Re: [patch] rtl8102e: commit 7bf6bf480 zeroized MAC address

From: Ivan Vecera <[email-masked]>
Date: Wed, 15 Oct 2008 14:31:57 +0200

[email-masked] wrote:
> Tested on top of linus tree and back ported 2.6.27.
> 
> Please cc me, thanks
> Martin Capitanio
> 
I think this one is more common.

Ivan

=====
Subject: [PATCH] [r8169] initialize MAC address found in EEPROM only if is it valid

Signed-off-by: Ivan Vecera <[email-masked]>
---
 drivers/net/r8169.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/net/r8169.c b/drivers/net/r8169.c
index c821da2..587a96c 100644
--- a/drivers/net/r8169.c
+++ b/drivers/net/r8169.c
@@ -1975,8 +1975,9 @@ static void rtl_init_mac_address(struct rtl8169_private *tp,
 
 	dprintk("MAC address found in EEPROM: %s\n", print_mac(buf, mac));
 
-	/* Write MAC address */
-	rtl_rar_set(tp, mac);
+	/* Write MAC address if is it valid */
+	if (is_valid_ether_addr(mac))
+		rtl_rar_set(tp, mac);
 }
 
 static int __devinit
-- 
1.5.6.3